@@ -1,16 +1,15 @@
 #!/bin/sh
 # Run this to generate all the initial makefiles, etc.
-
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
-PKG_NAME=libgdata
-
 (test -f $srcdir/configure.ac) || {
-	echo "**Error**: Directory "\`$srcdir\'" does not look like the top-level $PKG_NAME directory"
+	echo "**Error**: Directory "\`$srcdir\'" does not look like the top-level project directory"
 	exit 1
 }
 
+PKG_NAME=`autoconf --trace "AC_INIT:$1" "$srcdir/configure.ac"`
+
 if [ "$#" = 0 -a "x$NOCONFIGURE" = "x" ]; then
 	echo "**Warning**: I am going to run \`configure' with no arguments." >&2
 	echo "If you wish to pass any to it, please specify them on the" >&2
@@ -18,22 +17,19 @@ if [ "$#" = 0 -a "x$NOCONFIGURE" = "x" ]; then
 	echo "" >&2
 fi
 
-# if the AC_CONFIG_MACRO_DIR() macro is used, create that directory
-# This is a automake bug fixed in automake 1.13.2
-# See http://debbugs.gnu.org/cgi/bugreport.cgi?bug=13514
-if [ -n "m4" ]; then
-	mkdir -p m4
-fi
-
 set -x
 
+aclocal --install || exit 1
 gtkdocize --copy || exit 1
 intltoolize --force --copy --automake || exit 1
 autoreconf --verbose --force --install -Wno-portability || exit 1
 
-if test x$NOCONFIGURE = x; then
-	$srcdir/configure "$@" && \
-	echo "Now type \`make\' to compile $PKG_NAME" || exit 1
+if [ "$NOCONFIGURE" = "" ]; then
+	$srcdir/configure "$@" || exit 1
+
+	if [ "$1" = "--help" ]; then exit 0 else
+		echo "Now type \`make\' to compile $PKG_NAME" || exit 1
+	fi
 else
 	echo "Skipping configure process."
 fi
