@@ -652,6 +652,11 @@ get_json (GDataParsable *parsable, JsonBuilder *builder)
 		json_builder_add_string_value (builder, priv->id);
 	}
 
+	if (priv->summary != NULL) {
+		json_builder_set_member_name (builder, "description");
+		json_builder_add_string_value (builder, priv->summary);
+	}
+
 	if (priv->updated != -1) {
 		gchar *updated = gdata_parser_int64_to_iso8601 (priv->updated);
 		json_builder_set_member_name (builder, "updated");
@@ -819,6 +824,24 @@ gdata_entry_get_etag (GDataEntry *self)
 	return NULL;
 }
 
+/*
+ * _gdata_entry_set_etag:
+ * @self: a #GDataEntry
+ * @etag: the new ETag value
+ *
+ * Sets the value of the #GDataEntry:etag property to @etag.
+ *
+ * Since: 0.17.2
+ */
+void
+_gdata_entry_set_etag (GDataEntry *self, const gchar *etag)
+{
+	g_return_if_fail (GDATA_IS_ENTRY (self));
+
+	g_free (self->priv->etag);
+	self->priv->etag = g_strdup (etag);
+}
+
 /**
  * gdata_entry_get_updated:
  * @self: a #GDataEntry
@@ -920,8 +943,12 @@ gdata_entry_add_category (GDataEntry *self, GDataCategory *category)
 		GList *element;
 
 		if (klass->kind_term != NULL && g_strcmp0 (gdata_category_get_term (category), klass->kind_term) != 0) {
-			g_warning ("Adding a kind category term, '%s', to an entry of kind '%s'.",
-			           gdata_category_get_term (category), klass->kind_term);
+			/* This used to make sense as a warning, but the new
+			 * JSON APIs use a lot of different kinds for very
+			 * highly related JSON schemas, which libgdata uses a
+			 * single class for…so it makes less sense now. */
+			g_debug ("Adding a kind category term, '%s', to an entry of kind '%s'.",
+			         gdata_category_get_term (category), klass->kind_term);
 		}
 
 		/* If it is a kind category, remove the entry’s existing kind category to allow the new one
