@@ -2,6 +2,7 @@
 /*
  * GData Client
  * Copyright (C) Philip Withnall 2008–2010 <philip@tecnocode.co.uk>
+ * Copyright (C) Red Hat, Inc. 2015
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -55,7 +56,6 @@ static void get_xml (GDataParsable *parsable, GString *xml_string);
 static void get_namespaces (GDataParsable *parsable, GHashTable *namespaces);
 
 static void _gdata_feed_add_category (GDataFeed *self, GDataCategory *category);
-static void _gdata_feed_add_link (GDataFeed *self, GDataLink *link);
 static void _gdata_feed_add_author (GDataFeed *self, GDataAuthor *author);
 
 static gboolean parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GError **error);
@@ -282,7 +282,7 @@ gdata_feed_class_init (GDataFeedClass *klass)
 	/**
 	 * GDataFeed:total-results:
 	 *
-	 * The number of items in the result set for the feed, including those on other pages.
+	 * The number of items in the result set for the feed, including those on other pages. If this is zero, the total number is unknown.
 	 *
 	 * This should <emphasis>not</emphasis> be used manually for pagination. Instead, use a #GDataQuery and call its gdata_query_next_page()
 	 * or gdata_query_previous_page() functions before making the query to the service.
@@ -625,6 +625,19 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 
 			json_reader_end_element (reader);
 		}
+	} else if (g_strcmp0 (json_reader_get_member_name (reader), "selfLink") == 0) {
+		GDataLink *_link;
+		const gchar *uri;
+
+		/* Empty URI? */
+		uri = json_reader_get_string_value (reader);
+		if (uri == NULL || *uri == '\0') {
+			return gdata_parser_error_required_json_content_missing (reader, error);
+		}
+
+		_link = gdata_link_new (uri, GDATA_LINK_SELF);
+		_gdata_feed_add_link (self, _link);
+		g_object_unref (_link);
 	} else if (g_strcmp0 (json_reader_get_member_name (reader), "kind") == 0) {
 		/* Ignore. */
 	} else if (g_strcmp0 (json_reader_get_member_name (reader), "etag") == 0) {
@@ -844,7 +857,7 @@ gdata_feed_look_up_link (GDataFeed *self, const gchar *rel)
 	return GDATA_LINK (element->data);
 }
 
-static void
+void
 _gdata_feed_add_link (GDataFeed *self, GDataLink *_link)
 {
 	self->priv->links = g_list_prepend (self->priv->links, g_object_ref (_link));
@@ -1047,7 +1060,7 @@ gdata_feed_get_start_index (GDataFeed *self)
  * @self: a #GDataFeed
  *
  * Returns the total number of results in the result set, including results on other
- * pages.
+ * pages. If this is zero, the total number is unknown.
  *
  * Return value: the total number of results, or <code class="literal">0</code>
  **/
