@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009, 2010, 2014, 2015 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,7 +29,7 @@
  * access roles defined for the base #GDataAccessRule (e.g. %GDATA_ACCESS_ROLE_NONE), #GDataCalendarCalendar has its own, such as
  * %GDATA_CALENDAR_ACCESS_ROLE_EDITOR and %GDATA_CALENDAR_ACCESS_ROLE_FREE_BUSY.
  *
- * For more details of Google Calendar's GData API, see the <ulink type="http" url="http://code.google.com/apis/calendar/docs/2.0/reference.html">
+ * For more details of Google Calendar's GData API, see the <ulink type="http" url="https://developers.google.com/google-apps/calendar/v3/reference/">
  * online documentation</ulink>.
  *
  * <example>
@@ -77,7 +77,6 @@
 #include <config.h>
 #include <glib.h>
 #include <glib/gi18n-lib.h>
-#include <libxml/parser.h>
 #include <string.h>
 
 #include "gdata-calendar-calendar.h"
@@ -87,25 +86,22 @@
 #include "gdata-types.h"
 #include "gdata-access-handler.h"
 #include "gdata-calendar-service.h"
+#include "gdata-calendar-access-rule.h"
 
 static void gdata_calendar_calendar_access_handler_init (GDataAccessHandlerIface *iface);
-static GObject *gdata_calendar_calendar_constructor (GType type, guint n_construct_params, GObjectConstructParam *construct_params);
 static void gdata_calendar_calendar_finalize (GObject *object);
 static void gdata_calendar_calendar_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
 static void gdata_calendar_calendar_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
-static void get_xml (GDataParsable *parsable, GString *xml_string);
-static gboolean parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_data, GError **error);
-static void get_namespaces (GDataParsable *parsable, GHashTable *namespaces);
+static void get_json (GDataParsable *parsable, JsonBuilder *builder);
+static gboolean parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GError **error);
+static const gchar *get_content_type (void);
 
 struct _GDataCalendarCalendarPrivate {
 	gchar *timezone;
-	guint times_cleaned;
 	gboolean is_hidden;
 	GDataColor colour;
 	gboolean is_selected;
 	gchar *access_level;
-
-	gint64 edited;
 };
 
 enum {
@@ -131,16 +127,15 @@ gdata_calendar_calendar_class_init (GDataCalendarCalendarClass *klass)
 
 	g_type_class_add_private (klass, sizeof (GDataCalendarCalendarPrivate));
 
-	gobject_class->constructor = gdata_calendar_calendar_constructor;
 	gobject_class->set_property = gdata_calendar_calendar_set_property;
 	gobject_class->get_property = gdata_calendar_calendar_get_property;
 	gobject_class->finalize = gdata_calendar_calendar_finalize;
 
-	parsable_class->parse_xml = parse_xml;
-	parsable_class->get_xml = get_xml;
-	parsable_class->get_namespaces = get_namespaces;
+	parsable_class->parse_json = parse_json;
+	parsable_class->get_json = get_json;
+	parsable_class->get_content_type = get_content_type;
 
-	entry_class->kind_term = "http://schemas.google.com/gCal/2005#calendarmeta";
+	entry_class->kind_term = "calendar#calendarListEntry";
 
 	/**
 	 * GDataCalendarCalendar:timezone:
@@ -158,12 +153,18 @@ gdata_calendar_calendar_class_init (GDataCalendarCalendarClass *klass)
 	 * GDataCalendarCalendar:times-cleaned:
 	 *
 	 * The number of times the calendar has been cleared of events.
+	 *
+	 * Deprecated: 0.17.2: Unsupported by the online API any more. There
+	 *   is no replacement; this will always return
+	 *   <code class="literal">0</code>.
 	 **/
 	g_object_class_install_property (gobject_class, PROP_TIMES_CLEANED,
 	                                 g_param_spec_uint ("times-cleaned",
 	                                                    "Times cleaned", "The number of times the calendar has been cleared of events.",
 	                                                    0, G_MAXUINT, 0,
-	                                                    G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+	                                                    G_PARAM_DEPRECATED |
+	                                                    G_PARAM_READABLE |
+	                                                    G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GDataCalendarCalendar:is-hidden:
@@ -181,12 +182,13 @@ gdata_calendar_calendar_class_init (GDataCalendarCalendarClass *klass)
 	/**
 	 * GDataCalendarCalendar:color:
 	 *
-	 * The color used to highlight the calendar in the user's browser. This must be one of a limited set of colors listed in the
-	 * <ulink type="http" url="http://code.google.com/apis/calendar/data/2.0/reference.html#gCalcolor">online documentation</ulink>.
+	 * The background color used to highlight the calendar in the user’s
+	 * browser. This used to be restricted to a limited set of colours, but
+	 * since 0.17.2 may be any RGB colour.
 	 **/
 	g_object_class_install_property (gobject_class, PROP_COLOR,
 	                                 g_param_spec_boxed ("color",
-	                                                     "Color", "The color used to highlight the calendar in the user's browser.",
+	                                                     "Color", "The background color used to highlight the calendar in the user's browser.",
 	                                                     GDATA_TYPE_COLOR,
 	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
@@ -223,12 +225,17 @@ gdata_calendar_calendar_class_init (GDataCalendarCalendarClass *klass)
 	 *
 	 * For more information, see the <ulink type="http" url="http://www.atomenabled.org/developers/protocol/#appEdited">
 	 * Atom Publishing Protocol specification</ulink>.
+	 *
+	 * Deprecated: 0.17.2: Unsupported by the online API any more. There
+	 * is no replacement; this will always return -1.
 	 **/
 	g_object_class_install_property (gobject_class, PROP_EDITED,
 	                                 g_param_spec_int64 ("edited",
 	                                                     "Edited", "The last time the calendar was edited.",
 	                                                     -1, G_MAXINT64, -1,
-	                                                     G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
+	                                                     G_PARAM_DEPRECATED |
+	                                                     G_PARAM_READABLE |
+	                                                     G_PARAM_STATIC_STRINGS));
 
 	/* Override the ETag property since ETags don't seem to be supported for calendars. */
 	g_object_class_override_property (gobject_class, PROP_ETAG, "etag");
@@ -246,39 +253,91 @@ get_authorization_domain (GDataAccessHandler *self)
 	return gdata_calendar_service_get_primary_authorization_domain ();
 }
 
+static GDataFeed *
+get_rules (GDataAccessHandler *self,
+           GDataService *service,
+           GCancellable *cancellable,
+           GDataQueryProgressCallback progress_callback,
+           gpointer progress_user_data,
+           GError **error)
+{
+	GDataAccessHandlerIface *iface;
+	GDataAuthorizationDomain *domain = NULL;
+	GDataFeed *feed;
+	GDataLink *_link;
+	SoupMessage *message;
+	GList/*<unowned GDataCalendarAccessRule>*/ *rules, *i;
+	const gchar *calendar_id;
+
+	_link = gdata_entry_look_up_link (GDATA_ENTRY (self),
+	                                  GDATA_LINK_ACCESS_CONTROL_LIST);
+	g_assert (_link != NULL);
+
+	iface = GDATA_ACCESS_HANDLER_GET_IFACE (self);
+	if (iface->get_authorization_domain != NULL) {
+		domain = iface->get_authorization_domain (self);
+	}
+
+	message = _gdata_service_query (service, domain,
+	                                gdata_link_get_uri (_link), NULL,
+	                                cancellable, error);
+	if (message == NULL) {
+		return NULL;
+	}
+
+	g_assert (message->response_body->data != NULL);
+
+	feed = _gdata_feed_new_from_json (GDATA_TYPE_FEED,
+	                                  message->response_body->data,
+	                                  message->response_body->length,
+	                                  GDATA_TYPE_CALENDAR_ACCESS_RULE,
+	                                  progress_callback, progress_user_data,
+	                                  error);
+
+	/* Set the self link on all the ACL rules so they can be deleted.
+	 * Sigh. */
+	rules = gdata_feed_get_entries (feed);
+	calendar_id = gdata_entry_get_id (GDATA_ENTRY (self));
+
+	for (i = rules; i != NULL; i = i->next) {
+		const gchar *id;
+		gchar *uri = NULL;  /* owned */
+
+		/* Set the self link, which is needed for
+		 * gdata_service_delete_entry(). Unfortunately, it needs the
+		 * ACL ID _and_ the calendar ID. */
+		id = gdata_entry_get_id (GDATA_ENTRY (i->data));
+
+		if (id == NULL || calendar_id == NULL) {
+			continue;
+		}
+
+		uri = g_strconcat ("https://www.googleapis.com"
+		                   "/calendar/v3/calendars/",
+		                   calendar_id, "/acl/", id, NULL);
+		_link = gdata_link_new (uri, GDATA_LINK_SELF);
+		gdata_entry_add_link (GDATA_ENTRY (i->data), _link);
+		g_object_unref (_link);
+		g_free (uri);
+	}
+
+	g_object_unref (message);
+
+	return feed;
+}
+
 static void
 gdata_calendar_calendar_access_handler_init (GDataAccessHandlerIface *iface)
 {
 	iface->is_owner_rule = is_owner_rule;
 	iface->get_authorization_domain = get_authorization_domain;
+	iface->get_rules = get_rules;
 }
 
 static void
 gdata_calendar_calendar_init (GDataCalendarCalendar *self)
 {
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GDATA_TYPE_CALENDAR_CALENDAR, GDataCalendarCalendarPrivate);
-	self->priv->edited = -1;
-}
-
-static GObject *
-gdata_calendar_calendar_constructor (GType type, guint n_construct_params, GObjectConstructParam *construct_params)
-{
-	GObject *object;
-
-	/* Chain up to the parent class */
-	object = G_OBJECT_CLASS (gdata_calendar_calendar_parent_class)->constructor (type, n_construct_params, construct_params);
-
-	if (_gdata_parsable_is_constructed_from_xml (GDATA_PARSABLE (object)) == FALSE) {
-		GDataCalendarCalendarPrivate *priv = GDATA_CALENDAR_CALENDAR (object)->priv;
-		GTimeVal time_val;
-
-		/* Set the edited property to the current time (creation time). We don't do this in *_init() since that would cause
-		 * setting it from parse_xml() to fail (duplicate element). */
-		g_get_current_time (&time_val);
-		priv->edited = time_val.tv_sec;
-	}
-
-	return object;
 }
 
 static void
@@ -296,14 +355,17 @@ gdata_calendar_calendar_finalize (GObject *object)
 static void
 gdata_calendar_calendar_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec)
 {
-	GDataCalendarCalendarPrivate *priv = GDATA_CALENDAR_CALENDAR (object)->priv;
+	GDataCalendarCalendar *self = GDATA_CALENDAR_CALENDAR (object);
+	GDataCalendarCalendarPrivate *priv = self->priv;
 
 	switch (property_id) {
 		case PROP_TIMEZONE:
 			g_value_set_string (value, priv->timezone);
 			break;
 		case PROP_TIMES_CLEANED:
-			g_value_set_uint (value, priv->times_cleaned);
+			G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+			g_value_set_uint (value, gdata_calendar_calendar_get_times_cleaned (self));
+			G_GNUC_END_IGNORE_DEPRECATIONS
 			break;
 		case PROP_IS_HIDDEN:
 			g_value_set_boolean (value, priv->is_hidden);
@@ -318,7 +380,10 @@ gdata_calendar_calendar_get_property (GObject *object, guint property_id, GValue
 			g_value_set_string (value, priv->access_level);
 			break;
 		case PROP_EDITED:
-			g_value_set_int64 (value, priv->edited);
+			G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+			g_value_set_int64 (value,
+			                   gdata_calendar_calendar_get_edited (self));
+			G_GNUC_END_IGNORE_DEPRECATIONS
 			break;
 		case PROP_ETAG:
 			/* Never return an ETag */
@@ -360,113 +425,186 @@ gdata_calendar_calendar_set_property (GObject *object, guint property_id, const
 }
 
 static gboolean
-parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_data, GError **error)
+parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GError **error)
 {
 	gboolean success;
 	GDataCalendarCalendar *self = GDATA_CALENDAR_CALENDAR (parsable);
 
-	if (gdata_parser_is_namespace (node, "http://www.w3.org/2007/app") == TRUE &&
-	    gdata_parser_int64_time_from_element (node, "edited", P_REQUIRED | P_NO_DUPES, &(self->priv->edited), &success, error) == TRUE) {
+	/* FIXME: Unimplemented:
+	 *  - location
+	 *  - summaryOverride
+	 *  - colorId
+	 *  - foregroundColor
+	 *  - defaultReminders
+	 *  - notificationSettings
+	 *  - primary
+	 *  - deleted
+	 */
+
+	if (gdata_parser_string_from_json_member (reader, "timeZone", P_DEFAULT, &self->priv->timezone, &success, error) ||
+	    gdata_parser_color_from_json_member (reader, "backgroundColor", P_DEFAULT, &self->priv->colour, &success, error) ||
+	    gdata_parser_boolean_from_json_member (reader, "hidden", P_DEFAULT, &self->priv->is_hidden, &success, error) ||
+	    gdata_parser_boolean_from_json_member (reader, "selected", P_DEFAULT, &self->priv->is_selected, &success, error)) {
 		return success;
-	} else if (gdata_parser_is_namespace (node, "http://schemas.google.com/gCal/2005") == TRUE) {
-		if (xmlStrcmp (node->name, (xmlChar*) "timezone") == 0) {
-			/* gCal:timezone */
-			xmlChar *_timezone = xmlGetProp (node, (xmlChar*) "value");
-			if (_timezone == NULL)
-				return gdata_parser_error_required_property_missing (node, "value", error);
-			self->priv->timezone = (gchar*) _timezone;
-		} else if (xmlStrcmp (node->name, (xmlChar*) "timesCleaned") == 0) {
-			/* gCal:timesCleaned */
-			xmlChar *times_cleaned = xmlGetProp (node, (xmlChar*) "value");
-			if (times_cleaned == NULL)
-				return gdata_parser_error_required_property_missing (node, "value", error);
-			self->priv->times_cleaned = g_ascii_strtoull ((gchar*) times_cleaned, NULL, 10);
-			xmlFree (times_cleaned);
-		} else if (xmlStrcmp (node->name, (xmlChar*) "hidden") == 0) {
-			/* gCal:hidden */
-			if (gdata_parser_boolean_from_property (node, "value", &(self->priv->is_hidden), -1, error) == FALSE)
-				return FALSE;
-		} else if (xmlStrcmp (node->name, (xmlChar*) "color") == 0) {
-			/* gCal:color */
-			xmlChar *value;
-			GDataColor colour;
+	} else if (g_strcmp0 (json_reader_get_member_name (reader), "summary") == 0) {
+		gchar *summary = NULL;
 
-			value = xmlGetProp (node, (xmlChar*) "value");
-			if (value == NULL)
-				return gdata_parser_error_required_property_missing (node, "value", error);
-			if (gdata_color_from_hexadecimal ((gchar*) value, &colour) == FALSE) {
-				/* Error */
-				g_set_error (error, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_PROTOCOL_ERROR,
-				             /* Translators: the first parameter is the name of an XML element (including the angle brackets
-				              * ("<" and ">"), and the second parameter is the erroneous value (which was not in hexadecimal
-				              * RGB format).
-				              *
-				              * For example:
-				              *  The content of a <entry/gCal:color> element ("00FG56") was not in hexadecimal RGB format. */
-				             _("The content of a %s element (\"%s\") was not in hexadecimal RGB format."),
-				             "<entry/gCal:color>", value);
-				xmlFree (value);
+		g_assert (gdata_parser_string_from_json_member (reader,
+		                                                "summary",
+		                                                P_DEFAULT,
+		                                                &summary,
+		                                                &success,
+		                                                error));
 
-				return FALSE;
+		if (summary != NULL) {
+			gdata_entry_set_title (GDATA_ENTRY (parsable), summary);
+		}
+
+		g_free (summary);
+
+		return success;
+	} else if (g_strcmp0 (json_reader_get_member_name (reader), "description") == 0) {
+		gchar *description = NULL;
+
+		g_assert (gdata_parser_string_from_json_member (reader,
+		                                                "description",
+		                                                P_DEFAULT,
+		                                                &description,
+		                                                &success,
+		                                                error));
+
+		if (description != NULL) {
+			gdata_entry_set_summary (GDATA_ENTRY (parsable),
+			                         description);
+		}
+
+		g_free (description);
+
+		return success;
+	} else if (g_strcmp0 (json_reader_get_member_name (reader), "accessRole") == 0) {
+		gchar *access_role = NULL;
+
+		g_assert (gdata_parser_string_from_json_member (reader,
+		                                                "accessRole",
+		                                                P_DEFAULT,
+		                                                &access_role,
+		                                                &success,
+		                                                error));
+
+		if (access_role != NULL) {
+			const gchar *level;
+
+			/* Convert from v3 format to v2. */
+			if (g_strcmp0 (access_role, "freeBusyReader") == 0) {
+				level = GDATA_CALENDAR_ACCESS_ROLE_FREE_BUSY;
+			} else if (g_strcmp0 (access_role, "reader") == 0) {
+				level = GDATA_CALENDAR_ACCESS_ROLE_READ;
+			} else if (g_strcmp0 (access_role, "writer") == 0) {
+				level = GDATA_CALENDAR_ACCESS_ROLE_EDITOR;
+			} else if (g_strcmp0 (access_role, "owner") == 0) {
+				level = GDATA_CALENDAR_ACCESS_ROLE_OWNER;
+			} else {
+				level = access_role;
 			}
 
-			gdata_calendar_calendar_set_color (self, &colour);
-			xmlFree (value);
-		} else if (xmlStrcmp (node->name, (xmlChar*) "selected") == 0) {
-			/* gCal:selected */
-			if (gdata_parser_boolean_from_property (node, "value", &(self->priv->is_selected), -1, error) == FALSE)
-				return FALSE;
-		} else if (xmlStrcmp (node->name, (xmlChar*) "accesslevel") == 0) {
-			/* gCal:accesslevel */
-			self->priv->access_level = (gchar*) xmlGetProp (node, (xmlChar*) "value");
-			if (self->priv->access_level == NULL)
-				return gdata_parser_error_required_property_missing (node, "value", error);
-		} else {
-			return GDATA_PARSABLE_CLASS (gdata_calendar_calendar_parent_class)->parse_xml (parsable, doc, node, user_data, error);
+			self->priv->access_level = g_strdup (level);
 		}
+
+		g_free (access_role);
+
+		return success;
+	} else if (g_strcmp0 (json_reader_get_member_name (reader), "id") == 0) {
+		GDataLink *_link;
+		const gchar *id;
+		gchar *uri;
+
+		id = json_reader_get_string_value (reader);
+		if (id != NULL && *id != '\0') {
+			/* Calendar entries don’t contain their own selfLink,
+			 * so we have to add one manually. */
+			uri = g_strconcat ("https://www.googleapis.com/calendar/v3/calendars/", id, NULL);
+			_link = gdata_link_new (uri, GDATA_LINK_SELF);
+			gdata_entry_add_link (GDATA_ENTRY (parsable), _link);
+			g_object_unref (_link);
+			g_free (uri);
+
+			/* Similarly for the ACL link. */
+			uri = g_strconcat ("https://www.googleapis.com"
+			                   "/calendar/v3/calendars/", id,
+			                   "/acl", NULL);
+			_link = gdata_link_new (uri,
+			                        GDATA_LINK_ACCESS_CONTROL_LIST);
+			gdata_entry_add_link (GDATA_ENTRY (parsable), _link);
+			g_object_unref (_link);
+			g_free (uri);
+		}
+
+		return GDATA_PARSABLE_CLASS (gdata_calendar_calendar_parent_class)->parse_json (parsable, reader, user_data, error);
 	} else {
-		return GDATA_PARSABLE_CLASS (gdata_calendar_calendar_parent_class)->parse_xml (parsable, doc, node, user_data, error);
+		return GDATA_PARSABLE_CLASS (gdata_calendar_calendar_parent_class)->parse_json (parsable, reader, user_data, error);
 	}
 
 	return TRUE;
 }
 
 static void
-get_xml (GDataParsable *parsable, GString *xml_string)
+get_json (GDataParsable *parsable, JsonBuilder *builder)
 {
+	const gchar *id, *etag, *title, *description;
 	gchar *colour;
 	GDataCalendarCalendarPrivate *priv = GDATA_CALENDAR_CALENDAR (parsable)->priv;
 
-	/* Chain up to the parent class */
-	GDATA_PARSABLE_CLASS (gdata_calendar_calendar_parent_class)->get_xml (parsable, xml_string);
+	id = gdata_entry_get_id (GDATA_ENTRY (parsable));
+	if (id != NULL) {
+		json_builder_set_member_name (builder, "id");
+		json_builder_add_string_value (builder, id);
+	}
 
-	/* Add all the Calendar-specific XML */
-	if (priv->timezone != NULL)
-		gdata_parser_string_append_escaped (xml_string, "<gCal:timezone value='", priv->timezone, "'/>");
+	json_builder_set_member_name (builder, "kind");
+	json_builder_add_string_value (builder, "calendar#calendar");
 
-	if (priv->is_hidden == TRUE)
-		g_string_append (xml_string, "<gCal:hidden value='true'/>");
-	else
-		g_string_append (xml_string, "<gCal:hidden value='false'/>");
+	/* Add the ETag, if available. */
+	etag = gdata_entry_get_etag (GDATA_ENTRY (parsable));
+	if (etag != NULL) {
+		json_builder_set_member_name (builder, "etag");
+		json_builder_add_string_value (builder, etag);
+	}
 
-	colour = gdata_color_to_hexadecimal (&(priv->colour));
-	g_string_append_printf (xml_string, "<gCal:color value='%s'/>", colour);
+	/* Calendar labels titles as ‘summary’. */
+	title = gdata_entry_get_title (GDATA_ENTRY (parsable));
+	if (title != NULL) {
+		json_builder_set_member_name (builder, "summary");
+		json_builder_add_string_value (builder, title);
+	}
+
+	description = gdata_entry_get_summary (GDATA_ENTRY (parsable));
+	if (description != NULL) {
+		json_builder_set_member_name (builder, "description");
+		json_builder_add_string_value (builder, description);
+	}
+
+	/* Add all the calendar-specific JSON */
+	if (priv->timezone != NULL) {
+		json_builder_set_member_name (builder, "timeZone");
+		json_builder_add_string_value (builder, priv->timezone);
+	}
+
+	json_builder_set_member_name (builder, "hidden");
+	json_builder_add_boolean_value (builder, priv->is_hidden);
+
+	colour = gdata_color_to_hexadecimal (&priv->colour);
+	json_builder_set_member_name (builder, "backgroundColor");
+	json_builder_add_string_value (builder, colour);
 	g_free (colour);
 
-	if (priv->is_selected == TRUE)
-		g_string_append (xml_string, "<gCal:selected value='true'/>");
-	else
-		g_string_append (xml_string, "<gCal:selected value='false'/>");
+	json_builder_set_member_name (builder, "selected");
+	json_builder_add_boolean_value (builder, priv->is_selected);
 }
 
-static void
-get_namespaces (GDataParsable *parsable, GHashTable *namespaces)
+static const gchar *
+get_content_type (void)
 {
-	/* Chain up to the parent class */
-	GDATA_PARSABLE_CLASS (gdata_calendar_calendar_parent_class)->get_namespaces (parsable, namespaces);
-
-	g_hash_table_insert (namespaces, (gchar*) "gCal", (gchar*) "http://schemas.google.com/gCal/2005");
-	g_hash_table_insert (namespaces, (gchar*) "app", (gchar*) "http://www.w3.org/2007/app");
+	return "application/json";
 }
 
 /**
@@ -525,12 +663,14 @@ gdata_calendar_calendar_set_timezone (GDataCalendarCalendar *self, const gchar *
  * Gets the #GDataCalendarCalendar:times-cleaned property.
  *
  * Return value: the number of times the calendar has been totally emptied
+ * Deprecated: 0.17.2: Unsupported by the online API any more. There is no
+ *   replacement; this will always return <code class="literal">0</code>.
  **/
 guint
 gdata_calendar_calendar_get_times_cleaned (GDataCalendarCalendar *self)
 {
 	g_return_val_if_fail (GDATA_IS_CALENDAR_CALENDAR (self), 0);
-	return self->priv->times_cleaned;
+	return 0;
 }
 
 /**
@@ -654,10 +794,12 @@ gdata_calendar_calendar_get_access_level (GDataCalendarCalendar *self)
  * Gets the #GDataCalendarCalendar:edited property. If the property is unset, <code class="literal">-1</code> will be returned.
  *
  * Return value: the UNIX timestamp for the time the calendar was last edited, or <code class="literal">-1</code>
+ * Deprecated: 0.17.2: Unsupported by the online API any more. There is no
+ *   replacement; this will always return <code class="literal">-1</code>.
  **/
 gint64
 gdata_calendar_calendar_get_edited (GDataCalendarCalendar *self)
 {
 	g_return_val_if_fail (GDATA_IS_CALENDAR_CALENDAR (self), -1);
-	return self->priv->edited;
+	return -1;
 }
