@@ -20,7 +20,7 @@
 /**
  * SECTION:gdata-freebase-search-query
  * @short_description: GData Freebase query object
- * @stability: Unstable
+ * @stability: Stable
  * @include: gdata/services/freebase/gdata-freebase-query.h
  *
  * #GDataFreebaseQuery represents a collection of query parameters specific to the Google Freebase service.
@@ -228,7 +228,7 @@ build_filter_string (FilterNode *node,
 		g_assert (/* node->container.filter_type >= 0 && */
 		          node->container.filter_type < G_N_ELEMENTS (type_str));
 
-		g_string_append_printf (str, "(%s", type_str[node->container.type]);
+		g_string_append_printf (str, "(%s", type_str[node->container.filter_type]);
 
 		for (i = 0; i < node->container.child_nodes->len; i++)
 			build_filter_string (g_ptr_array_index (node->container.child_nodes, i), str);
@@ -246,9 +246,15 @@ build_filter_string (FilterNode *node,
 		break;
 	}
 	case NODE_LOCATION:
-		g_string_append_printf (str, "(within radius:%" G_GUINT64_FORMAT "m lon:%.4f lat:%.4f)",
-					node->location.radius, node->location.lon, node->location.lat);
+	{
+		gchar lon_str[G_ASCII_DTOSTR_BUF_SIZE], lat_str[G_ASCII_DTOSTR_BUF_SIZE];
+
+		g_ascii_formatd (lon_str, G_ASCII_DTOSTR_BUF_SIZE, "%.4f", node->location.lon);
+		g_ascii_formatd (lat_str, G_ASCII_DTOSTR_BUF_SIZE, "%.4f", node->location.lat);
+		g_string_append_printf (str, "(within radius:%" G_GUINT64_FORMAT "m lon:%s lat:%s)",
+					node->location.radius, lon_str, lat_str);
 		break;
+	}
 	default:
 		g_assert_not_reached ();
 		break;
