@@ -75,6 +75,11 @@ typedef struct {
 typedef struct {
 	/*< private >*/
 	GDataQueryClass parent;
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_g_reserved0) (void);
+	void (*_g_reserved1) (void);
 } GDataFreebaseSearchQueryClass;
 
 GType gdata_freebase_search_query_get_type (void) G_GNUC_CONST;
