@@ -20,7 +20,7 @@
 /**
  * SECTION:gdata-freebase-topic-result
  * @short_description: GData Freebase topic result object
- * @stability: Unstable
+ * @stability: Stable
  * @include: gdata/services/freebase/gdata-freebase-topic-result.h
  *
  * #GDataFreebaseTopicResult is a subclass of #GDataFreebaseResult that contains all or a subset of the information
@@ -346,7 +346,7 @@ reader_fill_object_gvalue (JsonReader *reader, TopicValueType type, GValue *valu
 {
 	GDataFreebaseTopicObject *object;
 
-	if (type != TYPE_OBJECT && type != TYPE_COMPOUND)
+	if (type != TYPE_OBJECT)
 		return FALSE;
 
 	object = reader_create_object (reader, type);
@@ -369,7 +369,7 @@ reader_fill_compound_gvalue (JsonReader *reader, TopicValueType type, GValue *va
 
 	object = reader_create_object (reader, type);
 
-	if (object != NULL)
+	if (object == NULL)
 		return FALSE;
 
 	json_reader_read_member (reader, "property");
