@@ -86,6 +86,11 @@ typedef struct {
 typedef struct {
 	/*< private >*/
 	GDataEntryClass parent;
+
+	/*< private >*/
+	/* Padding for future expansion */
+	void (*_g_reserved0) (void);
+	void (*_g_reserved1) (void);
 } GDataTasksTaskClass;
 
 GType gdata_tasks_task_get_type (void) G_GNUC_CONST;
