@@ -268,6 +268,7 @@ gdata_youtube_service_error_quark (void)
 	return g_quark_from_static_string ("gdata-youtube-service-error-quark");
 }
 
+static void gdata_youtube_service_batchable_init (GDataBatchableIface *iface);
 static void gdata_youtube_service_finalize (GObject *object);
 static void gdata_youtube_service_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
 static void gdata_youtube_service_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
@@ -288,7 +289,11 @@ enum {
 /* Reference: https://developers.google.com/youtube/v3/guides/authentication */
 _GDATA_DEFINE_AUTHORIZATION_DOMAIN (youtube, "youtube",
                                     "https://www.googleapis.com/auth/youtube")
-G_DEFINE_TYPE_WITH_CODE (GDataYouTubeService, gdata_youtube_service, GDATA_TYPE_SERVICE, G_IMPLEMENT_INTERFACE (GDATA_TYPE_BATCHABLE, NULL))
+_GDATA_DEFINE_AUTHORIZATION_DOMAIN (youtube_force_ssl, "youtube-force-ssl",
+                                    "https://www.googleapis.com/auth/youtube.force-ssl")
+G_DEFINE_TYPE_WITH_CODE (GDataYouTubeService, gdata_youtube_service, GDATA_TYPE_SERVICE,
+                         G_IMPLEMENT_INTERFACE (GDATA_TYPE_BATCHABLE,
+                                                gdata_youtube_service_batchable_init))
 
 static void
 gdata_youtube_service_class_init (GDataYouTubeServiceClass *klass)
@@ -324,6 +329,20 @@ gdata_youtube_service_class_init (GDataYouTubeServiceClass *klass)
 	                                                      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
+static gboolean
+gdata_youtube_service_batchable_is_supported (GDataBatchOperationType operation_type)
+{
+	/* Batch operation support was removed with v3 of the API:
+	 * https://developers.google.com/youtube/v3/guides/implementation/deprecated#Batch_Processing */
+	return FALSE;
+}
+
+static void
+gdata_youtube_service_batchable_init (GDataBatchableIface *iface)
+{
+	iface->is_supported = gdata_youtube_service_batchable_is_supported;
+}
+
 static void
 gdata_youtube_service_init (GDataYouTubeService *self)
 {
@@ -596,7 +615,12 @@ parent:
 static GList *
 get_authorization_domains (void)
 {
-	return g_list_prepend (NULL, get_youtube_authorization_domain ());
+	GList *authorization_domains = NULL;
+
+	authorization_domains = g_list_prepend (authorization_domains, get_youtube_authorization_domain ());
+	authorization_domains = g_list_prepend (authorization_domains, get_youtube_force_ssl_authorization_domain ());
+
+	return authorization_domains;
 }
 
 /**
@@ -1016,10 +1040,7 @@ gdata_youtube_service_upload_video (GDataYouTubeService *self, GDataYouTubeVideo
 	                                            SOUP_METHOD_POST,
 	                                            "https://www.googleapis.com/upload/youtube/v3/videos"
 	                                            "?part=snippet,status,"
-	                                                  "recordingDetails,"
-	                                                  "contentDetails,id,"
-	                                                  "statistics,"
-	                                                  "processingDetails",
+	                                                  "recordingDetails",
 	                                            GDATA_ENTRY (video), slug,
 	                                            content_type,
 	                                            cancellable);
