@@ -26,10 +26,7 @@
  * #GDataYouTubeVideo is a subclass of #GDataEntry to represent a single video on YouTube, either when uploading or querying.
  *
  * #GDataYouTubeVideo implements #GDataCommentable, allowing comments on videos
- * to be queried and added. However, the initial version of the v3 YouTube API
- * does not currently support comments, so all #GDataCommentable calls will
- * fail. It is hoped that the YouTube API will regain support for comments in
- * future.
+ * to be queried and added.
  *
  * For more details of YouTube’s GData API, see the
  * <ulink type="http" url="https://developers.google.com/youtube/v3/docs/">
@@ -85,6 +82,7 @@ static void gdata_youtube_video_finalize (GObject *object);
 static void gdata_youtube_video_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
 static void gdata_youtube_video_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
 static gboolean parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GError **error);
+static gboolean post_parse_json (GDataParsable *parsable, gpointer user_data, GError **error);
 static void get_json (GDataParsable *parsable, JsonBuilder *builder);
 static const gchar *get_content_type (void);
 static gchar *get_entry_uri (const gchar *id) G_GNUC_WARN_UNUSED_RESULT;
@@ -98,7 +96,7 @@ struct _GDataYouTubeVideoPrivate {
 	guint view_count;
 	guint favorite_count;
 	gchar *location;
-	GHashTable *access_controls;
+	GHashTable/*<owned utf8, GDataYouTubePermission>*/ *access_controls;
 
 	/* gd:rating attributes */
 	struct {
@@ -117,6 +115,7 @@ struct _GDataYouTubeVideoPrivate {
 	GDataMediaCategory *category;
 	guint duration;
 	gboolean is_private;
+	gchar *channel_id;  /* owned */
 
 	/* Location. */
 	gdouble latitude;
@@ -178,6 +177,7 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	gobject_class->finalize = gdata_youtube_video_finalize;
 
 	parsable_class->parse_json = parse_json;
+	parsable_class->post_parse_json = post_parse_json;
 	parsable_class->get_json = get_json;
 	parsable_class->get_content_type = get_content_type;
 
@@ -477,7 +477,8 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	 * GDataYouTubeVideo:latitude:
 	 *
 	 * The location as a latitude coordinate associated with this video. Valid latitudes range from <code class="literal">-90.0</code>
-	 * to <code class="literal">90.0</code> inclusive.
+	 * to <code class="literal">90.0</code> inclusive. Set to a value
+	 * outside this range to unset the location.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="https://developers.google.com/youtube/v3/docs/videos#recordingDetails.location.latitude">
@@ -488,14 +489,15 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	g_object_class_install_property (gobject_class, PROP_LATITUDE,
 	                                 g_param_spec_double ("latitude",
 	                                                      "Latitude", "The location as a latitude coordinate associated with this video.",
-	                                                      -90.0, 90.0, 0.0,
+	                                                      G_MINDOUBLE, G_MAXDOUBLE, G_MAXDOUBLE,
 	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GDataYouTubeVideo:longitude:
 	 *
 	 * The location as a longitude coordinate associated with this video. Valid longitudes range from <code class="literal">-180.0</code>
-	 * to <code class="literal">180.0</code> inclusive.
+	 * to <code class="literal">180.0</code> inclusive. Set to a value
+	 * outside this range to unset the location.
 	 *
 	 * For more information, see the
 	 * <ulink type="http" url="https://developers.google.com/youtube/v3/docs/videos#recordingDetails.location.longitude">
@@ -506,7 +508,7 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	g_object_class_install_property (gobject_class, PROP_LONGITUDE,
 	                                 g_param_spec_double ("longitude",
 	                                                      "Longitude", "The location as a longitude coordinate associated with this video.",
-	                                                      -180.0, 180.0, 0.0,
+	                                                      G_MINDOUBLE, G_MAXDOUBLE, G_MAXDOUBLE,
 	                                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
@@ -526,6 +528,8 @@ gdata_youtube_video_init (GDataYouTubeVideo *self)
 	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GDATA_TYPE_YOUTUBE_VIDEO, GDataYouTubeVideoPrivate);
 	self->priv->recorded = -1;
 	self->priv->access_controls = g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify) g_free, NULL);
+	self->priv->latitude = G_MAXDOUBLE;
+	self->priv->longitude = G_MAXDOUBLE;
 }
 
 static void
@@ -549,6 +553,7 @@ gdata_youtube_video_finalize (GObject *object)
 	g_free (priv->location);
 	g_hash_table_destroy (priv->access_controls);
 	g_strfreev (priv->keywords);
+	g_free (priv->channel_id);
 	g_free (priv->player_uri);
 	g_strfreev (priv->region_restriction_allowed);
 	g_strfreev (priv->region_restriction_blocked);
@@ -1016,7 +1021,7 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 
 		/* Parse all its properties. */
 		for (i = 0; i < (guint) json_reader_count_members (reader); i++) {
-			g_return_val_if_fail (json_reader_read_element (reader, i), NULL);
+			g_return_val_if_fail (json_reader_read_element (reader, i), FALSE);
 
 			if (GDATA_PARSABLE_GET_CLASS (self)->parse_json (GDATA_PARSABLE (self), reader, user_data, error) == FALSE) {
 				json_reader_end_element (reader);
@@ -1098,7 +1103,8 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 
 				g_free (description);
 			} else if (gdata_parser_strv_from_json_member (reader, "tags", P_DEFAULT, &priv->keywords, &success, error) ||
-			           thumbnails_from_json_member (reader, "thumbnails", P_DEFAULT, &priv->thumbnails, &success, error)) {
+			           thumbnails_from_json_member (reader, "thumbnails", P_DEFAULT, &priv->thumbnails, &success, error) ||
+			           gdata_parser_string_from_json_member (reader, "channelId", P_DEFAULT, &priv->channel_id, &success, error)) {
 				/* Fall through. */
 			} else if (gdata_parser_string_from_json_member (reader, "categoryId", P_DEFAULT, &category_id, &success, error)) {
 				if (success) {
@@ -1162,20 +1168,20 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 		} else if (g_strcmp0 (privacy_status, "public") == 0) {
 			priv->is_private = FALSE;
 			g_hash_table_insert (priv->access_controls,
-			                     (gpointer) "list",
+			                     g_strdup ("list"),
 			                     GINT_TO_POINTER (GDATA_YOUTUBE_PERMISSION_ALLOWED));
 		} else if (g_strcmp0 (privacy_status, "unlisted") == 0) {
 			/* See: ‘list’ on
 			 * https://developers.google.com/youtube/2.0/reference?csw=1#youtube_data_api_tag_yt:accessControl */
 			priv->is_private = FALSE;
 			g_hash_table_insert (priv->access_controls,
-			                     (gpointer) "list",
+			                     g_strdup ("list"),
 			                     GINT_TO_POINTER (GDATA_YOUTUBE_PERMISSION_DENIED));
 		}
 
 		json_reader_read_member (reader, "embeddable");
 		g_hash_table_insert (priv->access_controls,
-		                     (gpointer) GDATA_YOUTUBE_ACTION_EMBED,
+		                     g_strdup (GDATA_YOUTUBE_ACTION_EMBED),
 		                     GINT_TO_POINTER (json_reader_get_boolean_value (reader) ?
 		                                      GDATA_YOUTUBE_PERMISSION_ALLOWED :
 		                                      GDATA_YOUTUBE_PERMISSION_DENIED));
@@ -1272,7 +1278,8 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 		recording_date = json_reader_get_string_value (reader);
 		json_reader_end_member (reader);
 
-		if (!gdata_parser_int64_from_date (recording_date,
+		if (recording_date != NULL &&
+		    !gdata_parser_int64_from_date (recording_date,
 		                                   &priv->recorded)) {
 			/* Error */
 			gdata_parser_error_not_iso8601_format_json (reader,
@@ -1312,6 +1319,32 @@ parse_json (GDataParsable *parsable, JsonReader *reader, gpointer user_data, GEr
 	return TRUE;
 }
 
+static gboolean
+post_parse_json (GDataParsable *parsable, gpointer user_data, GError **error)
+{
+	GDataLink *_link = NULL;  /* owned */
+	const gchar *id;
+	gchar *uri = NULL;  /* owned */
+
+	/* Set the self link, which is needed for
+	 * gdata_service_delete_entry(). */
+	id = gdata_entry_get_id (GDATA_ENTRY (parsable));
+
+	if (id == NULL) {
+		return TRUE;
+	}
+
+	uri = _gdata_service_build_uri ("https://www.googleapis.com"
+	                                "/youtube/v3/videos"
+	                                "?id=%s", id);
+	_link = gdata_link_new (uri, GDATA_LINK_SELF);
+	gdata_entry_add_link (GDATA_ENTRY (parsable), _link);
+	g_object_unref (_link);
+	g_free (uri);
+
+	return TRUE;
+}
+
 static void
 get_json (GDataParsable *parsable, JsonBuilder *builder)
 {
@@ -1414,7 +1447,8 @@ get_json (GDataParsable *parsable, JsonBuilder *builder)
 		json_builder_add_string_value (builder, priv->location);
 	}
 
-	if (priv->latitude != G_MAXDOUBLE && priv->longitude != G_MAXDOUBLE) {
+	if (priv->latitude >= -90.0 && priv->latitude <= 90.0 &&
+	    priv->longitude >= -180.0 && priv->longitude <= 180.0) {
 		json_builder_set_member_name (builder, "location");
 		json_builder_begin_object (builder);
 
@@ -1463,8 +1497,7 @@ get_entry_uri (const gchar *id)
 	return _gdata_service_build_uri ("https://www.googleapis.com/youtube/v3/videos"
 	                                 "?part=contentDetails,id,"
 	                                       "recordingDetails,snippet,"
-	                                       "status,statistics,"
-	                                       "processingDetails"
+	                                       "status,statistics"
 	                                 "&id=%s", id);
 }
 
@@ -1477,24 +1510,53 @@ get_authorization_domain (GDataCommentable *self)
 static gchar *
 get_query_comments_uri (GDataCommentable *self)
 {
-	/* FIXME: Currently unsupported:
-	 * https://developers.google.com/youtube/v3/migration-guide#to_be_migrated */
-	return NULL;
+	const gchar *video_id;
+
+	video_id = gdata_entry_get_id (GDATA_ENTRY (self));
+
+	/* https://developers.google.com/youtube/v3/docs/commentThreads/list */
+	return _gdata_service_build_uri ("https://www.googleapis.com"
+	                                 "/youtube/v3/commentThreads"
+	                                 "?part=snippet"
+	                                 "&videoId=%s", video_id);
 }
 
+G_GNUC_INTERNAL void
+_gdata_youtube_comment_set_video_id (GDataYouTubeComment *self,
+                                     const gchar *video_id);
+G_GNUC_INTERNAL void
+_gdata_youtube_comment_set_channel_id (GDataYouTubeComment *self,
+                                       const gchar *channel_id);
+
 static gchar *
 get_insert_comment_uri (GDataCommentable *self, GDataComment *comment_)
 {
-	/* FIXME: Currently unsupported:
-	 * https://developers.google.com/youtube/v3/migration-guide#to_be_migrated */
-	return NULL;
+	const gchar *video_id, *channel_id;
+	GDataYouTubeVideoPrivate *priv = GDATA_YOUTUBE_VIDEO (self)->priv;
+
+	video_id = gdata_entry_get_id (GDATA_ENTRY (self));
+	channel_id = priv->channel_id;
+
+	/* https://developers.google.com/youtube/v3/docs/commentThreads/insert
+	 *
+	 * We have to set the video ID on the @comment_. */
+	_gdata_youtube_comment_set_video_id (GDATA_YOUTUBE_COMMENT (comment_),
+	                                     video_id);
+	_gdata_youtube_comment_set_channel_id (GDATA_YOUTUBE_COMMENT (comment_),
+	                                       channel_id);
+
+	return _gdata_service_build_uri ("https://www.googleapis.com"
+	                                 "/youtube/v3/commentThreads"
+	                                 "?part=snippet"
+	                                 "&shareOnGooglePlus=false");
 }
 
 static gboolean
 is_comment_deletable (GDataCommentable *self, GDataComment *comment_)
 {
 	/* FIXME: Currently unsupported:
-	 * https://developers.google.com/youtube/v3/migration-guide#to_be_migrated */
+	 * https://developers.google.com/youtube/v3/migration-guide#to_be_migrated
+	 * https://developers.google.com/youtube/v3/guides/implementation/comments#comments-delete */
 	return FALSE;
 }
 
@@ -1718,7 +1780,7 @@ strv_contains (const gchar * const *strv, const gchar *key)
 {
 	guint i;
 
-	for (i = 0; strv[i] != NULL; i++) {
+	for (i = 0; strv != NULL && strv[i] != NULL; i++) {
 		if (g_strcmp0 (strv[i], key) == 0) {
 			return TRUE;
 		}
@@ -1743,16 +1805,24 @@ gboolean
 gdata_youtube_video_is_restricted_in_country (GDataYouTubeVideo *self, const gchar *country)
 {
 	GDataYouTubeVideoPrivate *priv;
+	gboolean allowed_present, allowed_empty;
+	gboolean in_allowed, in_blocked;
 
 	g_return_val_if_fail (GDATA_IS_YOUTUBE_VIDEO (self), FALSE);
 	g_return_val_if_fail (country != NULL && *country != '\0', FALSE);
 
 	priv = self->priv;
 
-	return (!strv_contains ((const gchar * const *) priv->region_restriction_allowed, country) &&
-	        (strv_contains ((const gchar * const *) priv->region_restriction_blocked, country) ||
-	         priv->region_restriction_allowed == NULL ||
-	         priv->region_restriction_allowed[0] == NULL));
+	allowed_present = (priv->region_restriction_allowed != NULL);
+	allowed_empty = (allowed_present &&
+	                 priv->region_restriction_allowed[0] == NULL);
+
+	in_allowed = strv_contains ((const gchar * const *) priv->region_restriction_allowed, country);
+	in_blocked = strv_contains ((const gchar * const *) priv->region_restriction_blocked, country);
+
+	return ((allowed_present && !in_allowed) ||
+	        allowed_empty ||
+	        (in_blocked && !in_allowed));
 }
 
 /* References:
@@ -1883,7 +1953,7 @@ gdata_youtube_video_set_category (GDataYouTubeVideo *self, GDataMediaCategory *c
 	g_return_if_fail (GDATA_IS_MEDIA_CATEGORY (category));
 
 	g_object_ref (category);
-	g_object_unref (self->priv->category);
+	g_clear_object (&self->priv->category);
 	self->priv->category = category;
 	g_object_notify (G_OBJECT (self), "category");
 }
